#!/usr/bin/perl

use strict;
use Test::More qw(no_plan);

require_ok('Kwiki::Kwiki::Command::Init');
require_ok('Kwiki::Kwiki::Command::Source');
require_ok('Kwiki::Kwiki::Command::Lib');
require_ok('Kwiki::Kwiki::Command::Distfile');
